@@ -35,6 +35,9 @@ FAILEDOPERATION_FLOWHASDOCUMENT = 'FailedOperation.FlowHasDocument'
 # 流程未找到关联的电子文件信息，请检查操作步骤，检查参数，并在修改后重试。
 FAILEDOPERATION_FLOWHASNODOCUMENT = 'FailedOperation.FlowHasNoDocument'
 
+# 当前无可用的许可
+FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
+
 # 签署审核未通过，请先完成审核。
 FAILEDOPERATION_NOSIGNREVIEWPASS = 'FailedOperation.NoSignReviewPass'
 
@@ -248,6 +251,9 @@ INVALIDPARAMETER_INVALIDVERIFYCHANNEL = 'InvalidParameter.InvalidVerifyChannel'
 # 验证码不正确。
 INVALIDPARAMETER_INVALIDVERIFYCODE = 'InvalidParameter.InvalidVerifyCode'
 
+# Limit参数超出最大限制
+INVALIDPARAMETER_LIMIT = 'InvalidParameter.Limit'
+
 # 缺少必填控件的值。
 INVALIDPARAMETER_MISSINGREQUIREDCOMPONENTVALUE = 'InvalidParameter.MissingRequiredComponentValue'
 
@@ -260,6 +266,9 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # 不支持的通知类型，请检查并联系客服处理。
 INVALIDPARAMETER_NOTIFYTYPE = 'InvalidParameter.NotifyType'
 
+# 参数Offset不正确
+INVALIDPARAMETER_OFFSET = 'InvalidParameter.Offset'
+
 # 不合法的企业名称，请修改后重试。
 INVALIDPARAMETER_ORGANIZATIONNAME = 'InvalidParameter.OrganizationName'
 
